@@ -15,20 +15,20 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ErrorViewerURICheckerObserver.cpp,v 1.6.2.1 2004/11/15 15:08:50 chpe Exp $
+ *  $Id: ErrorViewerURICheckerObserver.cpp,v 1.9 2005/04/06 14:47:45 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
+#include "mozilla-config.h"
+
 #include "config.h"
-#endif
 
 #include "link-checker.h"
 
 #include "ErrorViewerURICheckerObserver.h"
 
-#define MOZILLA_STRICT_API
+#undef MOZILLA_INTERNAL_API
 #include <nsEmbedString.h>
-#undef MOZILLA_STRICT_API
+#define MOZILLA_INTERNAL_API 1
 #include <nsCOMPtr.h>
 #include <nsIChannel.h>
 #include <nsIDOMHTMLAnchorElement.h>
