@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extension.c,v 1.2 2004/09/26 16:07:58 chpe Exp $
+ *  $Id: extension.c,v 1.4 2005/01/28 22:30:13 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-page-info-extension.h"
 #include "page-info-dialog.h"
@@ -34,7 +32,7 @@ G_MODULE_EXPORT GType register_module (GTypeModule *module);
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
-	LOG ("Registering EphyPageInfoExtension")
+	LOG ("Registering EphyPageInfoExtension");
 
 #ifdef ENABLE_NLS
 	/* Initialize the i18n stuff */
